Lazy/Fuzzy
==========
- A sample ``FuzzyChoice`` alternative implementation based on
  ``LazyFunction`` and ``functools.partial``.
- Various usage examples of ``LazyFunction`` and ``LazyAttribute``.

Testing
-------
.. code-block:: sh

    pytest

or

.. code-block:: sh

    python manage.py test
